darkhistory.history.reionization.brem_cooling_rate — DarkHistory documentation

# darkhistory.history.reionization.brem_cooling_rate

`darkhistory.history.reionization.` `brem_cooling_rate`(xHII, xHeII, xHeIII, T_m, rs)

  Bremsstrahlung cooling rate.

  Parameters: | xHII : float n_HII/n_H. xHeII : float n_HeII/n_H. xHeIII : float n_HeIII/n_H. T_m : float Matter temperature in eV. rs : float Redshift (1+z).
  Returns: | float Bremsstrahlung cooling rate in eV s^-1. See astro-ph/0607331.

#### Previous topic

darkhistory.history.reionization.alphaA_recomb

#### Next topic

darkhistory.history.reionization.coll_exc_cooling_rate

### This Page

Show Source